"""
pyregg: Rare-Event Simulation for Random Geometric Graphs
==========================================================

Provides three estimators — Naïve Monte Carlo (naiveMC),
Conditional Monte Carlo (conditionalMC), and Importance Sampling (ISMC) —
for six rare-event examples in Gilbert graphs.

Submodules
----------
ec      : Edge count
md      : Maximum degree
mcc     : Maximum connected component
ntg     : Number of triangles
mcs     : Maximum clique size
planar  : Graph planarity

Example
-------
>>> import pyregg.ec as ec
>>> Z, RV, n = ec.ISMC(WindLen=10, GridRes=100, Kappa=0.5, IntRange=1.0, Level=12)
"""

from pyregg import ec, md, mcc, ntg, mcs, planar

__version__ = "0.1.0"
__author__ = "Sarat Moka, Christian Hirsch, Volker Schmidt, Dirk Kroese"
__all__ = ["ec", "md", "mcc", "ntg", "mcs", "planar"]
